==> ovirt-imageio-2.0.2.tar.gz: ovirt-imageio-2.0.2/ovirt_imageio/errors.py <==
# ovirt-imageio
# Copyright (C) 2015-2016 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

from __future__ import absolute_import


class Error(Exception):
    msg = "Overide this in a subclass"

    def __str__(self):
        return self.msg.format(self=self)


class PartialContent(Error):
    msg = "Requested {self.requested} bytes, available {self.available} bytes"

    def __init__(self, requested, available):
        self.requested = requested
        self.available = available


class InvalidTicket(Error):
    """Base class for ticket errors"""


class MissingTicketParameter(InvalidTicket):
    msg = "Required ticket parameter is missing: {self.parameter}"

    def __init__(self, parameter):
        self.parameter = parameter


class InvalidTicketParameter(InvalidTicket):
    msg = ("Invalid value for {self.parameter!r}: "
           "{self.value!r}: {self.reason}")

    def __init__(self, parameter, value, reason):
        self.parameter = parameter
        self.value = value
        self.reason = reason


class AuthorizationError(Error):
    msg = "You are not allowed to access this resource: {self.reason}"

    def __init__(self, reason):
        self.reason = reason


class UnsupportedOperation(Error):
    msg = "Operation not supported: {self.reason}"

    def __init__(self, reason):
        self.reason = reason


class TlsConfigurationError(Error):
    msg = ("TLS enabled (see [tls] section in daemon.conf), but not "
           "configured: ca_file = {self.ca_file}, cert_file = "
           "{self.cert_file}, key_file = {self.key_file}")

    def __init__(self, ca_file, cert_file, key_file):
        self.ca_file = ca_file
        self.cert_file = cert_file
        self.key_file = key_file

==> ovirt-imageio-2.0.5.tar.gz: ovirt-imageio-2.0.5/ovirt_imageio/errors.py <==
# ovirt-imageio
# Copyright (C) 2015-2016 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

from __future__ import absolute_import


class Error(Exception):
    msg = "Overide this in a subclass"

    def __str__(self):
        return self.msg.format(self=self)


class PartialContent(Error):
    msg = "Requested {self.requested} bytes, available {self.available} bytes"

    def __init__(self, requested, available):
        self.requested = requested
        self.available = available


class InvalidTicket(Error):
    """Base class for ticket errors"""


class MissingTicketParameter(InvalidTicket):
    msg = "Required ticket parameter is missing: {self.parameter}"

    def __init__(self, parameter):
        self.parameter = parameter


class InvalidTicketParameter(InvalidTicket):
    msg = ("Invalid value for {self.parameter!r}: "
           "{self.value!r}: {self.reason}")

    def __init__(self, parameter, value, reason):
        self.parameter = parameter
        self.value = value
        self.reason = reason


class AuthorizationError(Error):
    msg = "You are not allowed to access this resource: {self.reason}"

    def __init__(self, reason):
        self.reason = reason


class UnsupportedOperation(Error):
    msg = "Operation not supported: {self.reason}"

    def __init__(self, reason):
        self.reason = reason


class TlsConfigurationError(Error):
    msg = ("TLS enabled (see [tls] section in daemon.conf), but not "
           "configured: ca_file = {self.ca_file}, cert_file = "
           "{self.cert_file}, key_file = {self.key_file}")

    def __init__(self, ca_file, cert_file, key_file):
        self.ca_file = ca_file
        self.cert_file = cert_file
        self.key_file = key_file


class InvalidConfig(Error):
    msg = "Invalid configuration: {self.key} = {self.value}"

    def __init__(self, key, value):
        self.key = key
        self.value = value
